==> AsposeCellsCloud-CellsApi-25.9.tar.gz: AsposeCellsCloud-CellsApi-25.9/docs/model/DataLabels.md <==
# AsposeCellsCloud::Object::DataLabels 

## Load the model package
```perl
use AsposeCellsCloud::Object::DataLabels;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IsAutoText** | **boolean** | Indicates the text is auto generated. |
**IsDeleted** | **boolean** | A nullable boolean property "IsDeleted" indicating whether an object has been deleted. |
**LinkedSource** | **string** |  |
**Number** | **int** | Gets and sets the built-in number format. |
**NumberFormat** | **string** | Represents the format string for the DataLabels object. |
**NumberFormatLinked** | **boolean** | True if the number format is linked to the cells                         (so that the number format changes in the labels when it changes in the cells). |
**Position** | **string** | Represents the position of the data label. |
**RotationAngle** | **int** |  |
**Separator** | **string** | Gets or sets the separator type used for the data labels on a chart. |
**ShowBubbleSize** | **boolean** | Represents a specified chart's data label percentage value display behavior. True displays the percentage value. False to hide. |
**ShowCategoryName** | **boolean** | Represents a specified chart's data label category name display behavior.True to display the category name for the data labels on a chart. False to hide. |
**ShowLegendKey** | **boolean** | Represents a specified chart's data label legend key display behavior.                        True if the data label legend key is visible. |
**ShowPercentage** | **boolean** | Represents a specified chart's data label percentage value display behavior. True displays the percentage value. False to hide. |
**ShowSeriesName** | **boolean** | Returns or sets a Boolean to indicate the series name display behavior for the data labels on a chart.                        True to show the series name. False to hide. |
**ShowValue** | **boolean** | Represents a specified chart's data label values display behavior. True displays the values. False to hide. |
**Text** | **string** | Gets or sets the text of data label. |
**TextDirection** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**Area** | **Area** |  |
**AutoScaleFont** | **boolean** |  |
**BackgroundMode** | **string** |  |
**Border** | **Line** |  |
**Font** | **Font** |  |
**IsAutomaticSize** | **boolean** |  |
**IsInnerMode** | **boolean** |  |
**Shadow** | **boolean** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/DataLabels.md <==
# AsposeCellsCloud::Object::DataLabels 

## Load the model package
```perl
use AsposeCellsCloud::Object::DataLabels;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IsAutoText** | **boolean** | Indicates the text is auto generated. |
**IsDeleted** | **boolean** | A nullable boolean property "IsDeleted" indicating whether an object has been deleted. |
**LinkedSource** | **string** |  |
**Number** | **int** | Gets and sets the built-in number format. |
**NumberFormat** | **string** | Represents the format string for the DataLabels object. |
**NumberFormatLinked** | **boolean** | True if the number format is linked to the cells                         (so that the number format changes in the labels when it changes in the cells). |
**Position** | **string** | Represents the position of the data label. |
**RotationAngle** | **int** |  |
**Separator** | **string** | Gets or sets the separator type used for the data labels on a chart. |
**ShowBubbleSize** | **boolean** | Represents a specified chart's data label percentage value display behavior. True displays the percentage value. False to hide. |
**ShowCategoryName** | **boolean** | Represents a specified chart's data label category name display behavior.True to display the category name for the data labels on a chart. False to hide. |
**ShowLegendKey** | **boolean** | Represents a specified chart's data label legend key display behavior.                        True if the data label legend key is visible. |
**ShowPercentage** | **boolean** | Represents a specified chart's data label percentage value display behavior. True displays the percentage value. False to hide. |
**ShowSeriesName** | **boolean** | Returns or sets a Boolean to indicate the series name display behavior for the data labels on a chart.                        True to show the series name. False to hide. |
**ShowValue** | **boolean** | Represents a specified chart's data label values display behavior. True displays the values. False to hide. |
**Text** | **string** | Gets or sets the text of data label. |
**TextDirection** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**Area** | **Area** |  |
**AutoScaleFont** | **boolean** |  |
**BackgroundMode** | **string** |  |
**Border** | **Line** |  |
**Font** | **Font** |  |
**IsAutomaticSize** | **boolean** |  |
**IsInnerMode** | **boolean** |  |
**Shadow** | **boolean** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
